@@ -58,6 +58,12 @@ static NSString *prefix = @"0xHIGHFLYx";
   return NO;
 }
 
+- (NSArray *)getCookiesIfNeeded: (WOContext *)_ctx
+{
+  //Needs to be override by children if needed
+  return nil;
+}
+
 - (NSArray *)parseCredentials:(NSString *)_creds {
   if (![_creds isNotEmpty])
     return nil;
