@@ -26,7 +26,6 @@
 #if GNU_RUNTIME
 
 #if __GNU_LIBOBJC__ >= 20100911
-#  define sel_get_any_uid sel_getUid
 #  include <objc/runtime.h>
 #else
 #  include <objc/encoding.h>
@@ -152,7 +151,7 @@ static GetKeyValueBinding* newGetBinding(NSString* key, id instance)
     cbuf = malloc(clen + 1);
     [key getCString:cbuf]; cbuf[clen] = '\0';
     ckey = cbuf;
-    sel = sel_get_any_uid(ckey);
+    sel = sel_registerName(ckey);
     
     if (sel && (mth = class_get_instance_method(class, sel)) &&
         method_get_number_of_arguments(mth) == 2) {
@@ -326,7 +325,7 @@ static SetKeyValueBinding* newSetBinding(NSString* key, id instance)
     Strcat(sname, ckey);
     Strcat(sname, ":");
     sname[3] = islower((int)sname[3]) ? toupper((int)sname[3]) : sname[3];
-    sel = sel_get_any_uid(sname);
+    sel = sel_registerName(sname);
         
     if (sel && (mth = class_get_instance_method(class, sel)) &&
         method_get_number_of_arguments(mth) == 3 &&
@@ -966,7 +965,7 @@ static inline BOOL setValue(NSString* key, id instance, id value)
     strcpy(bufPtr, "ForKey:");
     if (kbuf) free(kbuf);
     
-    sel = sel_get_any_uid(buf);
+    sel = sel_registerName(buf);
     if (buf) free(buf);
     
     return sel != NULL ? [self performSelector:sel withObject:_key] : nil;
@@ -1531,11 +1530,7 @@ static void doubleIvarSetFunc(void* info1, void* info2, id self, id val) {
     strcpy(bufPtr, "ForKey:");
     if (kbuf) free(kbuf);
 
-#if NeXT_RUNTIME
-    sel = sel_getUid(buf);
-#else    
-    sel = sel_get_any_uid(buf);
-#endif
+    sel = sel_registerName(buf);
     if (buf) free(buf);
     
     return sel != NULL ? [self performSelector:sel withObject:_key] : nil;
