@@ -361,16 +361,12 @@ static inline int encode_base64(const char *_src, size_t _srcLen, char *_dest,
   
   // Encode the remaining one or two characters.
   switch (inLen % 3) {
-    case 0:
-      //out[outPos++] = '\n';
-      break;
     case 1:
       c1 = _src[inPos] & 0xFF;
       out[outPos++] = base64tab[(c1 & 0xFC) >> 2];
       out[outPos++] = base64tab[((c1 & 0x03) << 4)];
       out[outPos++] = '=';
       out[outPos++] = '=';
-      //out[outPos++] = '\n';
       break;
     case 2:
       c1 = _src[inPos++] & 0xFF;
@@ -379,9 +375,9 @@ static inline int encode_base64(const char *_src, size_t _srcLen, char *_dest,
       out[outPos++] = base64tab[((c1 & 0x03) << 4) | ((c2 & 0xF0) >> 4)];
       out[outPos++] = base64tab[((c2 & 0x0F) << 2)];
       out[outPos++] = '=';
-      //out[outPos++] = '\n';
       break;
   }
+
   out[outPos] = 0;
   *_destLen = outPos;
   return 0;
