@@ -25,10 +25,6 @@
 
 @implementation NGMimeContentLengthHeaderFieldGenerator
 
-+ (int)version {
-  return 2;
-}
-
 - (NSData *)generateDataForHeaderFieldNamed:(NSString *)_headerField
   value:(id)_value
 {
